Class: Quant::Indicators
- Inherits:
-
Object
- Object
- Quant::Indicators
- Defined in:
- lib/quant/indicators.rb,
lib/quant/indicators/ma.rb,
lib/quant/indicators/ping.rb,
lib/quant/indicators/indicator.rb,
lib/quant/indicators/indicator_point.rb
Overview
TODO: build an Indicator registry so new indicators can be added and used outside those shipped with the library.
Defined Under Namespace
Classes: Indicator, IndicatorPoint, Ma, MaPoint, Ping, PingPoint